#pragma once
#include "afxwin.h"

///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

#define VAX_CREATED_REASON_CODE_INCOMING_CALL	1001
#define VAX_CREATED_REASON_CODE_OUTGOING_CALL	1002
#define VAX_CREATED_REASON_CODE_MERGED			1003
#define VAX_CREATED_REASON_CODE_TRANSFERED		1004

#define VAX_CLOSED_REASON_CODE_HANGUP			2001
#define VAX_CLOSED_REASON_CODE_SESSION_LOST		2002
#define VAX_CLOSED_REASON_CODE_MERGED			2003
#define VAX_CLOSED_REASON_CODE_TRANSFERED		2004
#define VAX_CLOSED_REASON_CODE_REJECTED			2005
#define VAX_CLOSED_REASON_CODE_FAILED			2006
#define VAX_CLOSED_REASON_CODE_CANCELLED		2007
#define VAX_CLOSED_REASON_CODE_TIMEOUT			2008
#define VAX_CLOSED_REASON_CODE_CLOSED			2009

//////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

#define PLAY_WAVE_MODE_EXCLUSIVE				0
#define PLAY_WAVE_MODE_MIXED					1

#define TYPE_VOICE_NORMAL						100
#define TYPE_VOICE_USER							101
#define TYPE_VOICE_ADMIN						102

#define VAX_CALL_CHANNEL_ZERO					0
#define VAX_CALL_CHANNEL_ONE					1

#define VAX_CUSTOM_HEADER_REQ_ID_INVITE			0

#define VAX_PEER_TYPE_USER						3001
#define VAX_PEER_TYPE_LINE						3002
#define VAX_PEER_TYPE_DIRECT_PROXY				3003

#define DTMF_TYPE_RFC2833						0
#define DTMF_TYPE_INBAND						1
#define DTMF_TYPE_INFO							2

#define VAX_TRANSFER_TYPE_BLIND					401
#define VAX_TRANSFER_TYPE_CONSULT				402

#define VAX_CODEC_GSM610						0
#define VAX_CODEC_ILBC							1
#define VAX_CODEC_G711A							2
#define VAX_CODEC_G711U							3
#define VAX_CODEC_G729							4

///////////////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////////////

#define VAX_QUEUE_ALGO_HUNT_RANDOM					0
#define VAX_QUEUE_ALGO_FEWEST_ANSWERED				1
#define VAX_QUEUE_ALGO_LEAST_TALK_TIME				2
#define VAX_QUEUE_ALGO_LONGEST_WAIT_TIME			3
#define VAX_QUEUE_ALGO_PRIORITIZED_HUNT				4
#define VAX_QUEUE_ALGO_ROUND_ROBIN					5

#define VAX_QUEUE_MODE_FREE							0
#define VAX_QUEUE_MODE_ANY							1

#define VAX_QUEUE_PLAY_WAVE_EVENT_TYPE_MUSIC		0
#define VAX_QUEUE_PLAY_WAVE_EVENT_TYPE_RING			1

#define VAX_QUEUE_AGENT_AVAILABLE_STATUS            0
#define VAX_QUEUE_AGENT_UNAVAILABLE_STATUS			1

///////////////////////////////////////////////////////////////////////////////

#define VAX_RING_GROUP_ALGO_RING_ALL					0
#define VAX_RING_GROUP_ALGO_HUNT_RANDOM					1
#define VAX_RING_GROUP_ALGO_ROUND_ROBIN					2
#define VAX_RING_GROUP_ALGO_LEAST_ANSWERED				3
#define VAX_RING_GROUP_ALGO_LEAST_TALK_TIME				4
#define VAX_RING_GROUP_ALGO_LONGEST_WAITING				5
#define VAX_RING_GROUP_ALGO_PRIORITIZED_HUNT			6

#define VAX_RING_GROUP_MODE_FREE						0
#define VAX_RING_GROUP_MODE_ANY							1

///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

#import "..\Component (COM)\VaxTeleServerCOM.dll" rename_namespace("VaxTeleServer")

using namespace VaxTeleServer;

class CVaxServerCOM : public CCmdTarget
{
	DECLARE_DYNCREATE(CVaxServerCOM)

public:
	CVaxServerCOM();
	~CVaxServerCOM();

public:

	DWORD m_dwCookie;
	
	_IVaxServerSIPEvents* m_pVaxEvents;
	IVaxServerSIP* m_pVaxSIP;

	//------------------------------------------------------------------------------------------------------------------
	//-------------------------------			Functions Added
	//------------------------------------------------------------------------------------------------------------------
	
	BOOL LoadObjectCOM();
	void UnLoadObjectCOM();
	
private:

	BOOL m_bShowMsgBoxCOM;
	BOOL IsLoadedObjectCOM();

public:

	LONG GetVaxErrorCode(); 
	void SetLicenseKey(LPCTSTR sLicenseKey);

	BOOL SetListenPortRangeRTP(LONG nListenStartPort, LONG nListenEndPort);

	BOOL Initialize(LPCTSTR sDomainRealm, LPCTSTR sSIPListenIP, LONG nSIPListenPort, LPCTSTR sRTPListenIP, LONG nRTPListenPort);
	void UnInitialize();
		
	BOOL AddUser(LPCTSTR sUserName, LPCTSTR sPassword, LPCTSTR sCodecList);
	void RemoveUser(LPCTSTR sUserName);
	BOOL RegisterUserExpiry(LONG nExpiry);

	BOOL AcceptRegister(LONG nRegId);
	BOOL RejectRegister(LONG nRegId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	BOOL AuthRegister(LONG nRegId);

	BOOL AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sOutboundProxySIP, LPCTSTR sCodecList);
	void RemoveLine(LPCTSTR sLineName);

	BOOL RegisterLine(LPCTSTR sLineName, LONG nExpire);
	BOOL UnRegisterLine(LPCTSTR sLineName);
	
	BOOL AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG nProxyPort, LPCTSTR sCodecList);
	void RemoveDirectProxySIP(LPCTSTR sProxyName);

	BOOL AcceptCallSession(LONG nSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG nToPeerType, LPCTSTR sToPeerName, LONG nTimeout);
	BOOL RejectCallSession(LONG nSessionId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	BOOL CloseCallSession(LONG nSessionId);
		
	LONG DialCallSession(LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG nToPeerType, LPCTSTR sToPeerName, LONG nTimeout);

	/////////////////////////////////////////////////////////////////////////////////////////
	///////////////////////////////// RingGroup  ////////////////////////////////////////////

	BOOL AddRingGroup(LPCTSTR sGroupName);
	void RemoveRingGroup(LPCTSTR sGroupName);

	BOOL AddRingGroupAgent(LPCTSTR sGroupName, LPCTSTR sUserName);
	void RemoveRingGroupAgent(LPCTSTR sGroupName, LPCTSTR sUserName);

	void SetRingGroupProcessMode(LPCTSTR sGroupName, LONG nProcessMode, LONG nProcessType);
	BOOL SetRingGroupAgentPriority(LPCTSTR sGroupName, LPCTSTR sAgentName, LONG nPriority);

	BOOL AddCallSessionToRingGroup(LPCTSTR sGroupName, LPCTSTR sCallerName, LPCTSTR sCallerId, LONG nSessionId);

	///////////////////////////////////////////////////////////////////////////////////

	BOOL AddCallPickUpGroup(LPCTSTR sGroupName);
	void RemoveCallPickUpGroup(LPCTSTR sGroupName);

	BOOL AddCallPickUpGroupMember(LPCTSTR sGroupName, LPCTSTR sUserName);
	void RemoveCallPickUpGroupMember(LPCTSTR sGroupName, LPCTSTR sUserName);
		
	BOOL PickUpCall(LONG nSessionId, LPCTSTR sUserName);

	///////////////////////////////////////////////////////////////////////////////

	BOOL ParkCallSession(LONG nSessionId, LONG nChannelId, LONG nSlotId);
	BOOL ConnectToParkedCall(LONG nSessionId, LONG nChannelId, LONG nSlotId);

	//////////////////////////////////////////////////////////////////////////////

	BOOL AddQueue(LPCTSTR sQueueName);
	void RemoveQueue(LPCTSTR sQueueName);

	BOOL AddQueueAgent(LPCTSTR sQueueName, LPCTSTR sAgentName);

	void RemoveQueueAgent(LPCTSTR sQueueName, LPCTSTR sAgentName);
	void SetQueueAgentPriority(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nPriority);

	BOOL SetQueueAgentStatus(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nStatusId);
	void SetQueueProcessMode(LPCTSTR sQueueName, LONG nProcessMode, LONG nProcessType);
	
	BOOL AddCallSessionToQueue(LPCTSTR sQueueName, LPCTSTR sCallerName, LPCTSTR sCallerId, LONG nSessionId, LONG nTimeout);
	BOOL RemoveCallSessionFromQueue(LONG nSessionId);

	//////////////////////////////////////////////////////////////////////////////

	BOOL AddStealthListener(LONG nStealthSessionId, LONG nCapturePeerType, LPCTSTR sCapturePeerName, LONG nVoiceTypeId);
	
	//////////////////////////////////////////////////////////////////////////////

	LONG AcceptTransferBlind(LONG nTransfererSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sTransferTo, LONG nToPeerType, LPCTSTR sToPeerName, LONG nTimeout);
	LONG AcceptTransferConsult(LONG nTransfererSessionId, LONG nTransferToSessionId);
	void RejectTransfer(LONG nSessionId);

	//////////////////////////////////////////////////////////////////////////////

	BOOL PlayWaveStartToCallSession(LONG nSessionId, LONG nChannelId, LONG nWaveId, BOOL bLoopPlay, LONG nPlayPosPCM);
	void PlayWaveStopToCallSession(LONG nSessionId, LONG nChannelId, LONG nWaveId);
	
	BOOL PlayWaveSetVolumeToCallSession(LONG nSessionId, LONG nChannelId, LONG nWaveId, LONG nVolume);
	BOOL PlayWaveSetModeTypeToCallSession(LONG nSessionId, LONG nChannelId, LONG nPlayModeType);

	//////////////////////////////////////////////////////////////////////////////

	BOOL RecordWaveStartToCallSession(LONG nSessionId, LONG nChannelId, LPCTSTR sFileName);
	void RecordWaveStopToCallSession(LONG nSessionId,  LONG nChannelId);
	BOOL RecordWavePauseToCallSession(LONG nSessionId,  LONG nChannelId, BOOL bEnable);

	LONG LoadWaveFile(LPCTSTR sFileName);
	LONG LoadWavePCM(char* pDataPCM, LONG nSizePCM);

	void UnLoadWaveFile(LONG nWaveId);

	BOOL LoadMusicHold(LPCTSTR sFileName);
	void UnLoadMusicHold();

	BOOL AcceptOnHoldRequest(LONG nSessionId);
	BOOL AcceptOffHoldRequest(LONG nSessionId);

	BOOL AcceptChatMessage(LONG nChatMsgId, LONG nToPeerType, LPCTSTR sToPeerName);
	void RejectChatMessage(LONG nChatMsgId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	LONG SendChatMessageText(LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LPCTSTR sMsgText, LONG nToPeerType, LPCTSTR sToPeerName);

	BOOL AcceptChatStatusSubscribe(LONG nSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG nToPeerType, LPCTSTR sToPeerName);
	void RejectChatStatusSubscribe(LONG nSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo);

	BOOL OpenConferenceRoom(LPCTSTR sRoomName);
	void CloseConferenceRoom(LPCTSTR sRoomName);

	BOOL AddCallSessionToConferenceRoom(LPCTSTR sRoomName, LONG nSessionId, LONG nVoiceTypeId);
	BOOL RemoveCallSessionFromConferenceRoom(LONG nSessionId);

	BOOL PlayWaveStartToConferenceRoom(LPCTSTR sRoomName, LONG nWaveId, BOOL bLoopPlay, LONG nPlayPosPCM);
	BOOL PlayWaveStopToConferenceRoom(LPCTSTR sRoomName, LONG nWaveId);
	BOOL PlayWaveSetVolumeToConferenceRoom(LPCTSTR sRoomName, LONG nWaveId, LONG nVolume);

	BOOL RecordWaveStartToConferenceRoom(LPCTSTR sRoomName, LPCTSTR sFileName);
	BOOL RecordWaveStopToConferenceRoom(LPCTSTR sRoomName);
	BOOL RecordWavePauseToConferenceRoom(LPCTSTR sRoomName, BOOL bEnable);
		
	BOOL VoiceSessionLost(BOOL bEnable, LONG nTimeout);  // Seconds.
	
	LONG SendInfoVM(LPCTSTR sUserLogin, LONG nNewMsgCount, LONG nOldMsgCount, BOOL bMsgWaiting);
	
	BOOL StartVaxTeleTick(LONG nTickId, LONG nElapse); // milli seconds.
	BOOL StopVaxTeleTick(LONG nTickId);

	BOOL SetUserAgentName(LPCTSTR sName);
	CString GetUserAgentName();
	
	BOOL SetSessionNameSDP(LPCTSTR sName);
	CString GetSessionNameSDP();

	BOOL SendDTMFCallSession(LONG nSessionId, LONG nChannelId, LONG nTypeDTMF, LONG nDigit);
	BOOL DetectDigitDTMF(LONG nSessionId, LONG nChannelId, LONG nTypeDTMF, BOOL bEnable, LONG nMilliSecTimeout); //Milli Seconds.
		 
	BOOL DialToneToCallSession(BOOL bEnable, LONG nSessionId, LONG nWaveId);
	BOOL DiagnosticLogSIP(BOOL bInbound, BOOL bOutbound);

	LONG SplitCallSession(LONG nSessionId, LONG nChannelId);
	BOOL MoveCall(LONG nSrcSessionId, LONG nSrcChannelId, LONG nDscSessionId);
	
	BOOL CallSessionSendStatusResponse(LONG nSessionId, LONG nStatusCode, LPCTSTR sReasonPhrase, LPCTSTR sContactURI);
	BOOL CallSessionDetectAMD(LONG nSessionId, LONG nChannelId, BOOL bEnable, LONG nAnalysisTime, LONG nSilenceTime, LONG nSilenceCount);

	BOOL AddCustomHeader(LONG nReqId, LPCTSTR sName, LPCTSTR sValue);
	BOOL RemoveCustomHeader(LONG nReqId, LPCTSTR sName);
	BOOL RemoveCustomHeaderAll(LONG nReqId);

	LONG GetCallSessionTxCodec(LONG nSessionId, LONG nChannelId);
	LONG GetCallSessionRxCodec(LONG nSessionId, LONG nChannelId);

	BOOL BusyLampSubscribeAccept(LONG nSubScrbId, BOOL bAuthenticate, LONG nExpires);
	BOOL BusyLampSubscribeReject(LONG nSubScrbId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	BOOL BusyLampSendStatus(LPCTSTR sFromUserName, LPCTSTR sToUserName, LONG nStateId);

	BOOL AdjustCallSessionVoiceType(LONG nSessionId, LONG nChannelId, LONG nVoiceTypeId);

public:

	BOOL SetCallSessionData(LONG nSessionId, HANDLE hData);
	HANDLE GetCallSessionData(LONG nSessionId);
		
	BOOL SetUserData(LPCTSTR sUserName, HANDLE hData);
	HANDLE GetUserData(LPCTSTR sUserName);

	BOOL SetLineData(LPCTSTR sLineName, HANDLE hData);
	HANDLE GetLineData(LPCTSTR sLineName);

	BOOL SetDirectProxyData(LPCTSTR sProxyName, HANDLE hData);
	HANDLE GetDirectProxyData(LPCTSTR sProxyName);

	BOOL SetRegisterUserData(LPCTSTR sUserLogin, HANDLE hData);
	HANDLE GetRegisterUserData(LPCTSTR sUserLogin);

	BOOL SetConferenceRoomData(LPCTSTR sRoomName, HANDLE hData);
	HANDLE GetConferenceRoomData(LPCTSTR sRoomName);

public:

	BOOL TrvsUserStart();
	CString TrvsUserNext();

	BOOL TrvsLineStart();
	CString TrvsLineNext();

	BOOL TrvsDirectProxyStart();
	CString TrvsDirectProxyNext();

	BOOL TrvsCallSessionStart();
	LONG TrvsCallSessionNext();

	BOOL TrvsConferenceRoomStart();
	CString TrvsConferenceRoomNext();

	LONG GetCallCount();
	LONG GetUserCount();
	LONG GetLineCount();
	LONG GetDirectProxyCount();
	LONG GetCallSessionCount();
	LONG GetConferenceRoomCount();
	
public:

	LONG CustomListOpen(LONG nTableSize);
	BOOL CustomListClose(LONG nListId);
	
	BOOL CustomListAddData(LONG nListId, LPCTSTR sKey, HANDLE hData);
	BOOL CustomListRemoveData(LONG nListId, LPCTSTR sKey);
	HANDLE CustomListFindData(LONG nListId, LPCTSTR sKey);

	LONG CustomListCount(LONG nListId);
	BOOL CustomListTrvsStart(LONG nListId);
	HANDLE CustomListTrvsNext(LONG nListId);
	BOOL CustomListReset(LONG nListId);

public:

	CString GetCallSessionHeaderCallId(LONG nSessionId, LONG nChannelId);
	BOOL CallSessionMuteVoice(LONG nSessionId, LONG nChannelId, BOOL bListen, BOOL bSpeak);
	BOOL VideoCOMM(BOOL bEnable);

	BOOL SetExtDataREC(LONG nSessionId, LONG nChannelId, LPCTSTR sExtData);
	BOOL ConnectToServerREC(LONG nSessionId, LONG nChannelId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG nToPeerType, LPCTSTR sToPeerName, LONG nTimeout);

	BOOL AddNetworkRouteSIP(LPCTSTR sAssignedIP, LPCTSTR sRouterIP);
	BOOL AddNetworkRouteRTP(LPCTSTR sAssignedIP, LPCTSTR sRouterIP);

	
	BOOL RefreshCallSession(LONG nSessionId, LONG nChannelId, LPCTSTR sCallerName, LPCTSTR sCallerId, LONG nTimeout);
	LONG SendNotifyMsgSIP(LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG nToPeerType, LPCTSTR sToPeerName);
	
public:

	afx_msg virtual void OnFinalRelease();


///////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////

public:

	virtual void OnRegisterUser(LPCTSTR sUserLogin, LPCTSTR sDomain, LPCTSTR sUserAgent, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId);
	virtual void OnRegisterUserSuccess(LPCTSTR sUserLogin, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId);
	virtual void OnRegisterUserFailed(LPCTSTR sUserLogin, LPCTSTR sFromIP, LONG nFromPort, LONG nRegId);
	virtual void OnUnRegisterUser(LPCTSTR sUserLogin);
		
	virtual void OnCallSessionConnecting(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnCallSessionFailed(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnCallSessionConnected(LONG nSessionId);

	virtual void OnIncomingCall(LONG nSessionId, LPCTSTR sCallerName, LPCTSTR sCallerId, LPCTSTR sDialNo, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sUserAgent, LPCTSTR sFromIP, LONG nFromPort);
	
	virtual void OnCallSessionCreated(LONG nSessionId, LONG nReasonCode);
	virtual void OnCallSessionClosed(LONG nSessionId, LONG nChannelId, LONG nReasonCode);

	virtual void OnCallSessionLost(LONG nSessionId, LONG nChannelId);
	virtual void OnCallSessionHangup(LONG nSessionId, LONG nChannelId);
	virtual void OnCallSessionTimeout(LONG nSessionId, LONG nChannelId);
	virtual void OnCallSessionCancelled(LONG nSessionId);
	
	virtual void OnCallSessionOnHold(LONG nSessionId, LONG nChannelId);
	virtual void OnCallSessionOffHold(LONG nSessionId, LONG nChannelId);

	virtual void OnCallSessionTransferBlind(LONG nTransfererSessionId, LONG nTransfererChannelId, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo);
	virtual void OnCallSessionTransferConsult(LONG nTransfererSessionId, LONG nTransfereeSessionId, LONG nTransferToSessionId, LONG nTransfererChannelId, LONG nTransfereeChannelId, LONG nTransferToChannelId, LPCTSTR sTransferer, LPCTSTR sTransferee, LPCTSTR sTransferTo);
	
	virtual void OnCallSessionTransfering(LONG nSessionId, LONG nTransferType, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnCallSessionTransferFailed(LONG nSessionId, LONG nTransferType, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnCallSessionTransferTimeout(LONG nSessionId, LONG nTransferType, LONG nChannelId);
	virtual void OnCallSessionTransfered(LONG nSessionId, LONG nTransferType);

	virtual void OnLineRegisterTrying(LPCTSTR sLineName);
	virtual void OnLineRegisterFailed(LPCTSTR sLineName, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnLineRegisterSuccess(LPCTSTR sLineName);

	virtual void OnLineUnRegisterTrying(LPCTSTR sLineName);
	virtual void OnLineUnRegisterFailed(LPCTSTR sLineName, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnLineUnRegisterSuccess(LPCTSTR sLineName);
		
	virtual void OnChatMessageText(LONG nChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LPCTSTR sMsgText, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort);
	virtual void OnChatMessageTyping(LONG nChatMsgId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, BOOL IsTypingStart, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort);
	
	virtual void OnChatStatusSubscribe(LONG nSubscrbId, LPCTSTR sMsgFrom, LPCTSTR sMsgTo, LONG nFromPeerType, LPCTSTR sFromPeerName, LPCTSTR sFromIP, LONG nFromPort);
	virtual void OnChatStatusSendSubscribeSuccess(LONG nSubscrbId);
	virtual void OnChatStatusSendSubscribeFailed(LONG nSubscrbId, LONG nStatusCode, LPCTSTR sReasonPhrase);

	virtual void OnChatMessageSuccess(LONG nChatMsgId);
	virtual void OnChatMessageFailed(LONG nChatMsgId, LONG nStatusId, LPCTSTR sReasonPhrase);
	virtual void OnChatMessageTimeout(LONG nChatMsgId);

	virtual void OnOutgoingDiagnosticLog(LPCTSTR sMsgSIP, LPCTSTR sToIP, LONG nToPort);
	virtual void OnIncomingDiagnosticLog(LPCTSTR sMsgSIP, LPCTSTR sFromIP, LONG nFromPort);

	virtual void OnDetectedDigitDTMF(LONG nSessionId, LONG nChannelId, LPCTSTR sDigitDTMF);
	virtual void OnVaxTeleTick(LONG nTickId);

	virtual void OnSendTimeoutVM(LONG nMsgIdVM);
	virtual void OnSendSuccessVM(LONG nMsgIdVM);

	virtual void OnCallSessionDialToneStart(LONG nSessionId, LONG nChannelId, LONG nWaveId);
	virtual void OnCallSessionDialToneStop(LONG nSessionId, LONG nChannelId, LONG nWaveId);

	virtual void OnCallSessionPlayWaveDone(LONG nSessionId, LONG nChannelId, LONG nWaveId);
	virtual void OnConferenceRoomPlayWaveDone(LPCTSTR sRoomName, LONG nWaveId);
		
	virtual void OnCallSessionDetectedAMD(LONG nSessionId, LONG nChannelId, BOOL bIsHuman);

	virtual void OnCallSessionRecordedPCM(LONG nSessionId, LONG nChannelId, LONGLONG nDataPCM, LONG nSizePCM, LONG nTypePCM);
	virtual void OnConferenceRoomRecordedPCM(LPCTSTR sRoomName, LONGLONG nDataPCM, LONG nSizePCM, LONG nTypePCM);

	virtual void OnBusyLampSubscribe(LONG nSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, LONG nFromPort);
	virtual void OnBusyLampUnSubscribe(LONG nSubScrbId, LPCTSTR sUserName, LPCTSTR sToUserName, LPCTSTR sFromIP, LONG nFromPort);
	virtual void OnBusyLampSubscribeSuccess(LONG nSubScrbId, LPCTSTR sUserName);
	virtual void OnBusyLampSubscribeFailed(LONG nSubScrbId, LPCTSTR sUserName);
	virtual void OnBusyLampSendStatus(LPCTSTR sFromUserName, LPCTSTR sToUserName, LONG nStateId);

	virtual void OnVaxErrorLog(LPCTSTR sFuncName, LONG nErrorCode, LPCTSTR sErrorMsg);
	virtual void OnVaxLicenseChannel(LONG nTotalChannels, LONG nUsedChannels);
	
	virtual void OnAddCallSessionToQueueSuccess(LPCTSTR sQueueName, LONG nSessionId);
	virtual void OnAddCallSessionToQueueFailed(LPCTSTR sQueueName, LONG nSessionId);

	virtual void OnQueuePlayWaveStart(LONG nEventType, LPCTSTR sQueueName, LONG nSessionId);
	virtual void OnQueuePlayWaveStop(LONG nEventType, LPCTSTR sQueueName, LONG nSessionId);

	virtual void OnQueueAgentConnectStarted(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nSessionId);
	virtual void OnQueueAgentConnectTrying(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nSessionId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnQueueAgentConnectFailed(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nSessionId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnQueueAgentConnectTimeout(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nSessionId);
	virtual void OnQueueAgentConnectSuccess(LPCTSTR sQueueName, LPCTSTR sAgentName, LONG nSessionId);
	
	virtual void OnAddCallSessionToRingGroupSuccess(LPCTSTR sGroupName, LONG nSessionId);
	virtual void OnAddCallSessionToRingGroupFailed(LPCTSTR sGroupName, LONG nSessionId);

	virtual void OnServerConnectingREC(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnServerConnectedREC(LONG nSessionId, LONG nChannelId);
	virtual void OnServerFailedREC(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);
	virtual void OnServerTimeoutREC(LONG nSessionId, LONG nChannelId);
	virtual void OnServerHungupREC(LONG nSessionId, LONG nChannelId);

	virtual void OnSendReqTransferCallTimeout(LONG nSessionId, LONG nChannelId);
	virtual void OnSendReqTransferCallAccepted(LONG nSessionId, LONG nChannelId);
	virtual void OnSendReqTransferCallFailed(LONG nSessionId, LONG nChannelId, LONG nStatusCode, LPCTSTR sReasonPhrase);

	virtual void OnQualityReportPUBLISH(LPCTSTR sMsgSIP, LPCTSTR sMsgSDP, LPCTSTR sFromIP, LONG nFromPort);

	virtual void OnSendNotifyMsgSuccess(LONG nMsgId);
	virtual void OnSendNotifyMsgFailed(LONG nMsgId, LONG nStatusCode, LPCTSTR sReasonPhrase);

	DECLARE_MESSAGE_MAP()
	// Generated OLE dispatch map functions
	//{{AFX_DISPATCH(CVaxServerCOM)
						
	//}}AFX_DISPATCH

	DECLARE_DISPATCH_MAP()
	DECLARE_INTERFACE_MAP()

};

