// AddLoginDlg.cpp : implementation file
//

#include "stdafx.h"
#include "VaxTeleServerApp.h"
#include "VaxTeleServerAppDlg.h"
#include "AddLoginDlg.h"
#include "Codec.h"
#include "VaxServerSIP.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif



/////////////////////////////////////////////////////////////////////////////
// CAddLoginDlg dialog


CAddLoginDlg::CAddLoginDlg(CVaxServerSIP* pVaxTeleSIP) : CPropertyPage(CAddLoginDlg::IDD)
{
	//{{AFX_DATA_INIT(CAddLoginDlg)
	m_sPasswordSIP = _T("");
	m_bAccountBlocked = FALSE;
	m_sLoginSIP = _T("");
	//}}AFX_DATA_INIT

	m_sCallPrefix = _T("");
	m_sDialPrefix = _T("");

	m_psp.dwFlags &= ~PSP_HASHELP;  // Lose the Help button
	m_pVaxTeleSIP = pVaxTeleSIP;
}


void CAddLoginDlg::DoDataExchange(CDataExchange* pDX)
{
	CPropertyPage::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CAddLoginDlg)
	DDX_Control(pDX, IDC_COMBO_LOGIN, m_ctrlComboLogin);
	DDX_Control(pDX, IDC_LIST_ENABLE_CODEC, m_ctrlEnableCodecList);
	DDX_Control(pDX, IDC_LIST_DISABLE_CODEC, m_ctrlDisableCodecList);
	DDX_Text(pDX, IDC_EDIT_PWD_SIP, m_sPasswordSIP);
	DDX_Check(pDX, IDC_CHECK_BLOCK_ACCOUNT, m_bAccountBlocked);
	DDX_CBString(pDX, IDC_COMBO_LOGIN, m_sLoginSIP);
	//}}AFX_DATA_MAP
	DDX_Text(pDX, IDC_EDIT_DIAL_PLAN_DIAL_PREFIX, m_sDialPrefix);
	DDX_Text(pDX, IDC_EDIT_DIAL_PLAN_USER_PREFIX, m_sCallPrefix);
	DDX_Control(pDX, IDC_COMBO_LOGIN_ROUTES, m_ctrlComboLoginRoute);
}


BEGIN_MESSAGE_MAP(CAddLoginDlg, CPropertyPage)
	//{{AFX_MSG_MAP(CAddLoginDlg)
	ON_BN_CLICKED(IDC_BUTTON_LOGIN_ADD, OnButtonLoginAdd)
	ON_BN_CLICKED(IDC_BUTTON_REMOVE_LOGIN, OnButtonRemoveLogin)
	ON_BN_CLICKED(IDC_BUTTON_ENABLE_CODEC, OnButtonEnableCodec)
	ON_BN_CLICKED(IDC_BUTTON_DISABLE_CODEC, OnButtonDisableCodec)
	ON_CBN_SELCHANGE(IDC_COMBO_LOGIN, OnSelchangeComboLogin)
	ON_BN_CLICKED(IDC_BUTTON_CLEAR, OnButtonClear)
	ON_BN_CLICKED(IDC_BUTTON_LOGIN_HELP, OnButtonLoginHelp)
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CAddLoginDlg message handlers

BOOL CAddLoginDlg::OnSetActive()
{
	m_ctrlComboLoginRoute.ResetContent();
	
	AddUsers();
	AddLines();
	AddDirectProxies();

	ShowUserDetails();

	return CPropertyPage::OnSetActive();
}

BOOL CAddLoginDlg::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	
	m_ctrlComboLogin.SetWindowPos(NULL, 0, 0, 160, 150, SWP_NOMOVE|SWP_NOZORDER);
	LoadCodecs();

	return TRUE;  // return TRUE unless you set the focus to a control
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void CAddLoginDlg::OnButtonLoginAdd() 
{
	UpdateData();

	if(!AddLoginChecks())
		return;
		
	if(m_ctrlComboLogin.FindStringExact(0, m_sLoginSIP) != -1)
	{
		if(MessageBox("Login already exists, do you want to continue?", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_YESNO) == IDNO)
			return;
	}

	/////////////////////////////////////////////////////////////////////////////////////////

	CCodec objCodec;
	CString sCodecList;
	
	for(int nCount = 0; nCount < m_ctrlEnableCodecList.GetCount(); nCount++)
	{
		CString sCodecText;
		m_ctrlEnableCodecList.GetText(nCount, sCodecText);

		sCodecList += objCodec.GetCodecNo(sCodecText);
	}

	//////////////////////////////////////////////////////////////////////////////////////////
	
	CString sToPeerName;
	int nToPeerType = -1;

	int nCurSel = m_ctrlComboLoginRoute.GetCurSel();

	if(nCurSel != -1)
	{
		m_ctrlComboLoginRoute.GetLBText(nCurSel, sToPeerName);
		nToPeerType = m_ctrlComboLoginRoute.GetItemData(nCurSel);
	}

	//////////////////////////////////////////////////////////////////////////////////////////
	
	m_pVaxTeleSIP->RemoveUser(m_sLoginSIP);

	if(!m_pVaxTeleSIP->AddUser(m_sLoginSIP, m_sPasswordSIP, sCodecList, m_bAccountBlocked, m_sCallPrefix, m_sDialPrefix, nToPeerType, sToPeerName))
	{
		MessageBox("Login could not be created or Please start the server first.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return;
	}

	if(m_ctrlComboLogin.FindStringExact(0, m_sLoginSIP) == -1)
		m_ctrlComboLogin.AddString(m_sLoginSIP);
		
	MessageBox("Login added/updated successfully.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
}

void CAddLoginDlg::OnButtonRemoveLogin() 
{
	UpdateData();
	
	if(m_sLoginSIP.IsEmpty())
	{
		MessageBox("Please enter a login name.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return;
	}

	int nIndex = m_ctrlComboLogin.FindStringExact(0, m_sLoginSIP);
	if(nIndex == -1) return;

	m_pVaxTeleSIP->RemoveUser(m_sLoginSIP);
	m_ctrlComboLogin.DeleteString(nIndex);	
	
	ClearDlgContent();
	
	if(m_ctrlComboLogin.GetCount() > 0)
		m_ctrlComboLogin.SetCurSel(0);
		
	ShowUserDetails();
	
	MessageBox("Login removed successfully!", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void CAddLoginDlg::OnButtonEnableCodec() 
{
	int nCurSel = m_ctrlDisableCodecList.GetCurSel();
	if(nCurSel == -1) return;

	CString sCurSelText;
	
	m_ctrlDisableCodecList.GetText(nCurSel, sCurSelText);
	m_ctrlDisableCodecList.DeleteString(nCurSel);
	
	m_ctrlEnableCodecList.AddString(sCurSelText);
}

void CAddLoginDlg::OnButtonDisableCodec() 
{
	int nCurSel = m_ctrlEnableCodecList.GetCurSel();
	if(nCurSel == -1) return;

	CString sCurSelText;
	m_ctrlEnableCodecList.GetText(nCurSel, sCurSelText);
	m_ctrlEnableCodecList.DeleteString(nCurSel);
	
	m_ctrlDisableCodecList.AddString(sCurSelText);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

BOOL CAddLoginDlg::AddLoginChecks()
{
	if(m_sLoginSIP.IsEmpty())
	{
		MessageBox("Please enter login.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	CString sDigits = "0123456789";
	for(int nIndex = 0; nIndex < m_sLoginSIP.GetLength(); nIndex++)
	{
		if(sDigits.Find(m_sLoginSIP.GetAt(nIndex)) == -1)
		{
			MessageBox("Login should contain only numerals 0 through 9.\n\nFor example: 12 or 324323 or 800122 or 2109756 etc.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
			return FALSE;
		}
	}
		
	if(m_sPasswordSIP.IsEmpty())
	{
		MessageBox("Please enter login password.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}
		
	if(m_sLoginSIP.GetLength() > 20 || m_sPasswordSIP.GetLength() > 20)
	{
		MessageBox("Login and password size should not be more 20.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	if(m_sLoginSIP.Left(2) == "00")
	{
		MessageBox("Please donot enter 00 as login prefix. 00 prefix is use to prepare dial plan.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	if(m_ctrlEnableCodecList.GetCount() == 0)
	{
		MessageBox("Please select a codec.", "VaxTeleSIP", MB_ICONEXCLAMATION|MB_OK);
		return FALSE;
	}

	return TRUE;
}

void CAddLoginDlg::ClearDlgContent()
{
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	m_ctrlEnableCodecList.AddString(G711U_TEXT);
	m_ctrlEnableCodecList.AddString(G711A_TEXT);
	m_ctrlEnableCodecList.AddString(ILBC_TEXT);
	m_ctrlEnableCodecList.AddString(G610_TEXT);
	m_ctrlEnableCodecList.AddString(G729_TEXT);

	m_sLoginSIP    = "";
	m_sPasswordSIP = "";
		
	m_bAccountBlocked = FALSE;
	m_ctrlComboLoginRoute.SetCurSel(-1);

	UpdateData(FALSE);
}

void CAddLoginDlg::OnSelchangeComboLogin() 
{
	ShowUserDetails();
}

void CAddLoginDlg::OnButtonClear() 
{
	ClearDlgContent();
}

void CAddLoginDlg::LoadCodecs()
{
	CCodec objCodec;
	
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	for(char cCodec = '0'; cCodec < TOTAL_NO_CODEC; cCodec++)	
		m_ctrlEnableCodecList.AddString(objCodec.GetCodecName(cCodec));
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void CAddLoginDlg::AddUsers()
{
	m_ctrlComboLogin.ResetContent();

	CStringList objListUsers;
	m_pVaxTeleSIP->GetUserAll(&objListUsers);
		
	while(!objListUsers.IsEmpty())
	{
		m_ctrlComboLogin.AddString(objListUsers.RemoveHead());
	}
		
	if(m_ctrlComboLogin.GetCount() > 0)
		m_ctrlComboLogin.SetCurSel(0);
}

void CAddLoginDlg::AddLines()
{
	CStringList objLineList;
	m_pVaxTeleSIP->GetLineAll(&objLineList);
			
	while(!objLineList.IsEmpty())
	{
		CString sLineName = objLineList.RemoveHead();

		int nIndex = m_ctrlComboLoginRoute.AddString(sLineName);
		m_ctrlComboLoginRoute.SetItemData(nIndex, VAX_PEER_TYPE_LINE);
	}

	if(m_ctrlComboLoginRoute.GetCount() > 0)
		m_ctrlComboLoginRoute.SetCurSel(0);
}

void CAddLoginDlg::AddDirectProxies()
{
	CStringList objProxyList;
	m_pVaxTeleSIP->GetDirectProxyAll(&objProxyList);
	
	while(!objProxyList.IsEmpty())
	{
		CString sProxyName = objProxyList.RemoveHead();
		
		int nIndex = m_ctrlComboLoginRoute.AddString(sProxyName);
		m_ctrlComboLoginRoute.SetItemData(nIndex, VAX_PEER_TYPE_DIRECT_PROXY);
	}

	if(m_ctrlComboLoginRoute.GetCount() > 0)
		m_ctrlComboLoginRoute.SetCurSel(0);
}

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

void CAddLoginDlg::ShowUserDetails()
{
	int nCurIndex = m_ctrlComboLogin.GetCurSel();
	if(nCurIndex == -1) return;

	CString sLoginSIP;
	m_ctrlComboLogin.GetLBText(nCurIndex, sLoginSIP);
				
	CString sConnectName, sPassword, sUserPrefix;
	CString sDialPrefix, sCodecList, sToPeerName;
	int nToPeerType = -1; BOOL bBlocked;
		
	m_pVaxTeleSIP->GetUserDetails(sLoginSIP, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	UpdateDlgContent(sLoginSIP, sPassword, sCodecList, sDialPrefix, sUserPrefix, sToPeerName, bBlocked);
}

void CAddLoginDlg::UpdateDlgContent(LPCTSTR sLoginSIP, LPCTSTR sPassword, CString sCodecList, LPCTSTR sDialPrefix, LPCTSTR sUserPrefix, LPCTSTR sToPeerName, BOOL bBlocked)
{
	UpdateData();
		
	m_sPasswordSIP = sPassword;
	m_sLoginSIP = sLoginSIP;

	CCodec objCodec;
	
	m_ctrlEnableCodecList.ResetContent();
	m_ctrlDisableCodecList.ResetContent();

	for(char cCodec = '0'; cCodec < TOTAL_NO_CODEC; cCodec++)	
		m_ctrlDisableCodecList.AddString(objCodec.GetCodecName(cCodec));
	
	for(int nCount = 0; nCount < sCodecList.GetLength(); nCount++)
	{
		CString sCodecName = objCodec.GetCodecName(sCodecList.GetAt(nCount));
		m_ctrlEnableCodecList.AddString(sCodecName);
		
		int nIndex = m_ctrlDisableCodecList.FindStringExact(0, sCodecName);
		if(nIndex == -1) continue;
		
		m_ctrlDisableCodecList.DeleteString(nIndex);
	}

	m_sCallPrefix = sUserPrefix;
	m_sDialPrefix = sDialPrefix;
	
	m_ctrlComboLoginRoute.SetCurSel(-1);
	int nIndex = m_ctrlComboLoginRoute.FindStringExact(0, sToPeerName);
	
	if( nIndex != -1)
		m_ctrlComboLoginRoute.SetCurSel(nIndex);

	m_bAccountBlocked  = bBlocked;
	
	UpdateData(FALSE);
}

void CAddLoginDlg::OnButtonLoginHelp() 
{
	
}