#include "stdafx.h"
#include "VaxServerSIP.h"
#include "StatusLogDlg.h"
#include "ErrorLogDlg.h"
#include "StoreRegistry.h"
#include "StoreUser.h"
#include "StoreLine.h"
#include "StoreDirectProxy.h"
#include "StoreRoom.h"
#include "StoreCOMM.h"
#include "VaxSettingDefault.h"

#define HOLD_MUSIC_FILE  "..\\WaveFiles\\Hold.wav"
#define DIAL_TONE_MUSIC_FILE  "..\\WaveFiles\\DialTone.wav"


CVaxServerSIP::CVaxServerSIP()
{
	m_pVaxSettingDefault = new CVaxSettingDefault(this);
}

CVaxServerSIP::~CVaxServerSIP()
{
	delete m_pVaxSettingDefault;
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::Initialize(LPCTSTR sDomainRealm, LPCTSTR sSIPListenIP, int nSIPListenPort)
{
	CStoreCOMM objStoreCOMM;
	if(!objStoreCOMM.Initialize(sDomainRealm , sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
		return FALSE;

   if(!CVaxServerExCOM::Initialize(sDomainRealm, sSIPListenIP, nSIPListenPort, sSIPListenIP, -1))
	   return FALSE;

   CVaxServerExCOM::SetListenPortRangeRTP(20000, 30000);
   return TRUE;
}

BOOL CVaxServerSIP::GetInitialize(CString& sSIPListenIP,  int& nSIPListenPort)
{
	CStoreCOMM objCOMM;
	CString sDomainRealm, sRTPListenIP;
	int nRTPListenPort = -1;

	if(!objCOMM.GetInitialize(sDomainRealm, sSIPListenIP, nSIPListenPort,sRTPListenIP, nRTPListenPort))
		return FALSE;

	return TRUE;
}

BOOL CVaxServerSIP::LoadMusicHold(LPCTSTR sFileName)
{
	CStoreCOMM objCOMM;
    objCOMM.SetMusicHold(sFileName);

	return CVaxServerExCOM::LoadMusicHold(sFileName);
}

CString CVaxServerSIP::GetMusicHold()
{
	CStoreCOMM objCOMM;
	CString sFileName;

	if(!objCOMM.GetMusicHold(sFileName))
		sFileName = HOLD_MUSIC_FILE;

	return sFileName;
}

BOOL CVaxServerSIP::LoadMusicDialTone(LPCTSTR sFileName)
{
	CStoreCOMM objCOMM;
    objCOMM.SetMusicDialTone(sFileName);

	return CVaxServerExCOM::LoadMusicDialTone(sFileName);
}

CString CVaxServerSIP::GetDialToneMusic()
{
	CStoreCOMM objCOMM;
    CString sFileName;
    
	if(!objCOMM.GetMusicDialTone(sFileName))
		sFileName = DIAL_TONE_MUSIC_FILE;

	return sFileName;
}

///////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddUser(LPCTSTR sLogin, LPCTSTR sPassword, LPCTSTR sCodecList, BOOL bBlocked, LPCTSTR sUserPrefix, LPCTSTR sDialPrefix, int nToPeerType, LPCTSTR sToPeerName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreUser objStoreUser;
	objStoreUser.AddUser(sLogin, sPassword, sCodecList, bBlocked);

	CString sCallPrefixRoute, sDialPrefixRoute;

	sCallPrefixRoute = sUserPrefix;
	sDialPrefixRoute = sDialPrefix;

	if(!sCallPrefixRoute.IsEmpty() || !sDialPrefixRoute.IsEmpty())
	{
		objStoreUser.AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

		CVaxServerExCOM::AddUserRoute(sLogin, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	}

	return CVaxServerExCOM::AddUser(sLogin, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
}

void CVaxServerSIP::RemoveUser(LPCTSTR sLogin)
{
	if(!CVaxServerExCOM::IsInitialized())
	   return;

	CStoreUser objStoreUser;

	objStoreUser.RemoveUserRoute(sLogin);
	objStoreUser.RemoveUser(sLogin);

	CVaxServerExCOM::RemoveUserRoute(sLogin);
	CVaxServerExCOM::RemoveUser(sLogin);
}

 BOOL CVaxServerSIP::GetUserDetails(LPCTSTR sUserName, CString& sPassword, CString& sCodecList, BOOL& bBlocked, CString& sUserPrefix, CString& sDialPrefix,  int& nToPeerType, CString& sToPeerName)
 {
	 if(!CVaxServerExCOM::IsInitialized())
    	return FALSE;

	CStoreUser objStoreUSer;

    objStoreUSer.GetUser(sUserName, sPassword, sCodecList, bBlocked);
    objStoreUSer.GetUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);

    return TRUE;
 }

void CVaxServerSIP::GetUserAll(CStringList* pUsreList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

    CStoreUser objStoreUSer;
	objStoreUSer.GetUserAll(pUsreList);
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddLine(LPCTSTR sLineName, LPCTSTR sDisplayName, LPCTSTR sUserName, LPCTSTR sAuthUser, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxySIP, LPCTSTR sCodecList, BOOL bRegister, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreLine objStoreLine;
	objStoreLine.AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, "", sCodecList, bRegister);
	objStoreLine.AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);

	CVaxServerExCOM::AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
	return CVaxServerExCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerSIP::RemoveLine(LPCTSTR sLineName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreLine objStoreLine;

	objStoreLine.RemoveLine(sLineName);
	objStoreLine.RemoveLineRoute(sLineName);

	CVaxServerExCOM::RemoveLine(sLineName);
	CVaxServerExCOM::RemoveLineRoute(sLineName);
}

BOOL CVaxServerSIP::GetLineDetails(LPCTSTR sLineName, CString& sDisplayName, CString& sUserName, CString& sAuthUser, CString& sAuthPwd, CString& sDomainRealm, CString& sProxySIP, CString& sCodecList, BOOL& bRegister, int& nToPeerType, CString& sToPeerName, BOOL& bRejected, CString& sRoomName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreLine objStoreLine;
	CString sOutBountProxySIP;

	objStoreLine.GetLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sOutBountProxySIP, sCodecList, bRegister);
	objStoreLine.GetLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);

	return TRUE;
}

void CVaxServerSIP::GetLineAll(CStringList* pLineList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreLine objStoreLine;
	objStoreLine.GetLineAll(pLineList);
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddDirectProxySIP(LPCTSTR sProxyName, LPCTSTR sAuthLogin, LPCTSTR sAuthPwd, LPCTSTR sDomainRealm, LPCTSTR sProxyIP, LONG lProxyPort, LPCTSTR sCodecList, int nToPeerType, LPCTSTR sToPeerName, BOOL bRejected, LPCTSTR sRoomName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

    CStoreDirectProxy bojDirectProxy;
	bojDirectProxy.AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
	bojDirectProxy.AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);
	
	CVaxServerExCOM::AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);
	return CVaxServerExCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bRejected, sRoomName);
}

void CVaxServerSIP::RemoveDirectProxySIP(LPCTSTR sProxyName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreDirectProxy bojDirectProxy;
	bojDirectProxy.RemoveDirectProxySIP(sProxyName);
	bojDirectProxy.RemoveDirectProxyRoute(sProxyName);

	CVaxServerExCOM::RemoveDirectProxyRoute(sProxyName);
	CVaxServerExCOM::RemoveDirectProxySIP(sProxyName);
}

BOOL CVaxServerSIP::GetDirectProxyDetails(LPCTSTR sProxyName, CString& sAuthLogin, CString& sAuthPwd, CString& sDomainRealm, CString& sProxyIP, LONG& nProxyPort, CString& sCodecList, int& nToPeerType, CString& sToPeerName, BOOL& bRejected, CString& sRoomName)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreDirectProxy bojDirectProxy;
    bojDirectProxy.GetDirectyProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, nProxyPort, sCodecList);
	bojDirectProxy.GetDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejected, sRoomName);

	return TRUE;
}

BOOL CVaxServerSIP::GetDirectProxyAll(CStringList* pDirectProxyList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreDirectProxy bojDirectProxy;
	bojDirectProxy.GetDirectProxyAll(pDirectProxyList);

    return TRUE;
}

/////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////

BOOL CVaxServerSIP::AddRoom(LPCTSTR sRoomName, LPCTSTR sRoomNo)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	RemoveRoom(sRoomName);
	
	if(!CVaxServerExCOM::AddRoom(sRoomName, sRoomNo))
		return FALSE;

	CStoreRoom objStoreRoom;
    objStoreRoom.AddRoom(sRoomName, sRoomNo);

	return TRUE;
}

void CVaxServerSIP::RemoveRoom(LPCTSTR sRoomName)
{
    if(!CVaxServerExCOM::IsInitialized())
		return;

	CStoreRoom objStoreRoom;
    objStoreRoom.RemoveRoom(sRoomName);

	CVaxServerExCOM::RemoveRoom(sRoomName);
}

BOOL CVaxServerSIP::GetRoomDetails(LPCTSTR sRoomName, CString& sRoomNo)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

	CStoreRoom objRoom;
	objRoom.GetRoom(sRoomName, sRoomNo);

	return TRUE;
}

BOOL CVaxServerSIP::GetRoomAll(CStringList* pRoomList)
{
	if(!CVaxServerExCOM::IsInitialized())
		return FALSE;

    CStoreRoom objRoom;
   	objRoom.GetRoomAll(pRoomList);

    return TRUE;
}

//////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////

void CVaxServerSIP::LoadUser()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListUsers;

	CStoreUser objStoreUser;
	objStoreUser.GetUserAll(&objListUsers);

	if(objListUsers.GetCount()== 0)
		return;
    
	CString sUserName, sPassword, sCodecList, sUserPrefix, sDialPrefix, sToPeerName;
    
	BOOL bBlocked= FALSE;
    int nToPeerType = -1;
	
	POSITION posList = NULL;

	for(int nIndex = 0; nIndex < objListUsers.GetCount(); nIndex++)
	{
		posList = objListUsers.FindIndex(nIndex);
		if(posList == NULL)
			continue;
		
		sUserName = objListUsers.GetAt(posList); 

		objStoreUser.GetUser( sUserName, sPassword, sCodecList, bBlocked);
		objStoreUser.GetUserRoute(sUserName, sUserPrefix, sDialPrefix,  nToPeerType, sToPeerName);

		if(sUserPrefix.GetLength() !=0 || sDialPrefix.GetLength() !=0)
		{
		   CVaxServerExCOM::AddUserRoute(sUserName, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
		}

		CVaxServerExCOM::AddUser(sUserName, sPassword, sCodecList, bBlocked, sUserPrefix, sDialPrefix, nToPeerType, sToPeerName);
	}
}

void CVaxServerSIP::LoadLine()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListLine;

	CStoreLine objStoreLine;
	objStoreLine.GetLineAll(&objListLine);

	if(objListLine.GetCount() == 0)
		return;
    
	CString sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sCodecList, sProxySIP, sOutboundProxySIP, sToPeerName, sRoomName;

	BOOL bRejected = FALSE;
	BOOL bRegister = FALSE;

	int nToPeerType = -1;

	POSITION posList = NULL;

	for(int nIndex = 0; nIndex < objListLine.GetCount(); nIndex++)
	{
        posList = objListLine.FindIndex(nIndex);

		if(posList == NULL)
			continue;

		sLineName = objListLine.GetAt(posList); 

		objStoreLine.GetLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sOutboundProxySIP, sCodecList, bRegister);
        objStoreLine.GetLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);

		CVaxServerExCOM::AddLine(sLineName, sDisplayName, sUserName, sAuthUser, sAuthPwd, sDomainRealm, sProxySIP, sCodecList, bRegister, nToPeerType, sToPeerName, bRejected,sRoomName);
		CVaxServerExCOM::AddLineRoute(sLineName, nToPeerType, sToPeerName, bRejected, sRoomName);
	}
}

void CVaxServerSIP::LoadDirectProxy()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

   	CStringList objListDirectProxy;

	CStoreDirectProxy objStoreProxy;
	objStoreProxy.GetDirectProxyAll(&objListDirectProxy);

	if(objListDirectProxy.GetCount() == 0)
		return;

	CString sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, sCodecList, sToPeerName, sRoomName;

	LONG lProxyPort = -1;
	int nToPeerType = -1;

	BOOL bRejecteded = FALSE;

	POSITION posList = NULL;

	for(int nIndex = 0; nIndex < objListDirectProxy.GetCount(); nIndex++)
	{
		posList = objListDirectProxy.FindIndex(nIndex);

		if(posList == NULL)
			continue;

		sProxyName = objListDirectProxy.GetAt(posList);

		objStoreProxy.GetDirectyProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList);
		objStoreProxy.GetDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejecteded, sRoomName);

		CVaxServerExCOM::AddDirectProxySIP(sProxyName, sAuthLogin, sAuthPwd, sDomainRealm, sProxyIP, lProxyPort, sCodecList, nToPeerType, sToPeerName, bRejecteded, sRoomName);
		CVaxServerExCOM::AddDirectProxyRoute(sProxyName, nToPeerType, sToPeerName, bRejecteded, sRoomName);
	}

}

void CVaxServerSIP::LoadRoom()
{
	if(!CVaxServerExCOM::IsInitialized())
		return;

	CStringList objListConfRoom;

	CStoreRoom objRoom;
	objRoom.GetRoomAll(&objListConfRoom);

	if(objListConfRoom.GetCount() == 0)
		return;

	CString sRoomName , sRoomNo;
	POSITION posList = NULL;

	for(int nIndex = 0; nIndex < objListConfRoom.GetCount(); nIndex++)
	{
		posList = objListConfRoom.FindIndex(nIndex);

		if(posList == NULL)
			continue;

		sRoomName = objListConfRoom.GetAt(posList);

		objRoom.GetRoom(sRoomName, sRoomNo);
		CVaxServerExCOM::AddRoom(sRoomName, sRoomNo);
	}

}

/////////////////////////////////////////////////////////////////////////////
/////////////////////////////////////////////////////////////////////////////

void CVaxServerSIP::OnInitialize()
{
	if(!m_pVaxSettingDefault->LoadUserDefault())
	{
		LoadUser();
	}
	
	if(!m_pVaxSettingDefault->LoadLineDefault())
	{
		LoadLine();
	}
	
	if(!m_pVaxSettingDefault->LoadRoomDefault())
	{
		LoadRoom();
	}
                        
	LoadDirectProxy();
}

void CVaxServerSIP::OnStatusLog(LPCTSTR sStatus)
{
	m_pStatusLogDlg->OnStatusLog(sStatus);
}

void CVaxServerSIP::OnErrorLog(LPCTSTR sError)
{
	m_pErrorLogDlg->OnErrorLog(sError);
}